==> huhk-1.9.1.tar.gz: huhk-1.9.1/service/app_a/asserts/content/asserts_content_topic4c.py <==
import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_topic4c import SqlsContentTopic4C


class AssertsContentTopic4C(SqlsContentTopic4C):
    @allure.step(title="接口返回结果校验")
    def assert_content_topic4c_del(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_topic4c_del(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["topicId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_topic4c_getcontentlist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_topic4c_getcontentlist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["topicId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_topic4c_list(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_topic4c_list(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["topicId", "endTime", "createBy", "startTime", "keyWord"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_topic4c_insert(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_topic4c_insert(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["topicId", "topicTitle", "author"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_topic4c_top(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_topic4c_top(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["topicId", "type"])
        assert True, "数据比较不一致"

==> huhk-1.9.6.tar.gz: huhk-1.9.6/service/app_a/asserts/content/asserts_content_topic4c.py <==
import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_topic4c import SqlsContentTopic4C


class AssertsContentTopic4C(SqlsContentTopic4C):
    @allure.step(title="接口返回结果校验")
    def assert_content_topic4c_del(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_topic4c_del(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["topicId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_topic4c_getcontentlist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_topic4c_getcontentlist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["topicId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_topic4c_list(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_topic4c_list(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["createBy", "keyWord", "endTime", "startTime", "topicId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_topic4c_insert(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_topic4c_insert(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["topicId", "author", "topicTitle"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_topic4c_top(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_topic4c_top(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["topicId", "type"])
        assert True, "数据比较不一致"
